@@ -4,11 +4,12 @@ use crate::handler::{Handler, Traverse};
 use crate::swc_util::StringRepr;
 use crate::ProgramRef;
 use deno_ast::swc::common::Span;
+use deno_ast::swc::common::Spanned;
 use deno_ast::view as ast_view;
-use deno_ast::view::Spanned;
 use once_cell::sync::Lazy;
 use regex::{Captures, Regex};
 use std::collections::{BTreeMap, BTreeSet};
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct Camelcase;
@@ -16,8 +17,8 @@ pub struct Camelcase;
 const CODE: &str = "camelcase";
 
 impl LintRule for Camelcase {
-  fn new() -> Box<Self> {
-    Box::new(Camelcase)
+  fn new() -> Arc<Self> {
+    Arc::new(Camelcase)
   }
 
   fn tags(&self) -> &'static [&'static str] {
