@@ -19,6 +19,7 @@ use std::collections::{BTreeMap, HashMap};
 use std::iter;
 use std::mem;
 use std::rc::Rc;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct PreferConst;
@@ -38,8 +39,8 @@ enum PreferConstHint {
 }
 
 impl LintRule for PreferConst {
-  fn new() -> Box<Self> {
-    Box::new(PreferConst)
+  fn new() -> Arc<Self> {
+    Arc::new(PreferConst)
   }
 
   fn tags(&self) -> &'static [&'static str] {
