@@ -6,6 +6,7 @@ use deno_ast::swc::visit::noop_visit_type;
 use deno_ast::swc::visit::Node;
 use deno_ast::swc::visit::Visit;
 use derive_more::Display;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct SingleVarDeclarator;
@@ -19,8 +20,8 @@ enum SingleVarDeclaratorMessage {
 }
 
 impl LintRule for SingleVarDeclarator {
-  fn new() -> Box<Self> {
-    Box::new(SingleVarDeclarator)
+  fn new() -> Arc<Self> {
+    Arc::new(SingleVarDeclarator)
   }
 
   fn code(&self) -> &'static str {
