@@ -5,6 +5,7 @@ use deno_ast::swc::visit::noop_visit_type;
 use deno_ast::swc::visit::Node;
 use deno_ast::swc::visit::Visit;
 use derive_more::Display;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct UseIsNaN;
@@ -28,8 +29,8 @@ enum UseIsNaNMessage {
 }
 
 impl LintRule for UseIsNaN {
-  fn new() -> Box<Self> {
-    Box::new(UseIsNaN)
+  fn new() -> Arc<Self> {
+    Arc::new(UseIsNaN)
   }
 
   fn tags(&self) -> &'static [&'static str] {
@@ -145,6 +146,40 @@ impl<'c, 'view> Visit for UseIsNaNVisitor<'c, 'view> {
 mod tests {
   use super::*;
 
+  #[test]
+  fn use_isnan_valid() {
+    assert_lint_ok! {
+      UseIsNaN,
+      "var x = NaN;",
+      "isNaN(NaN) === true;",
+      "isNaN(123) !== true;",
+      "Number.isNaN(NaN) === true;",
+      "Number.isNaN(123) !== true;",
+      "foo(NaN + 1);",
+      "foo(1 + NaN);",
+      "foo(NaN - 1)",
+      "foo(1 - NaN)",
+      "foo(NaN * 2)",
+      "foo(2 * NaN)",
+      "foo(NaN / 2)",
+      "foo(2 / NaN)",
+      "var x; if (x = NaN) { }",
+      "var x = Number.NaN;",
+      "isNaN(Number.NaN) === true;",
+      "Number.isNaN(Number.NaN) === true;",
+      "foo(Number.NaN + 1);",
+      "foo(1 + Number.NaN);",
+      "foo(Number.NaN - 1)",
+      "foo(1 - Number.NaN)",
+      "foo(Number.NaN * 2)",
+      "foo(2 * Number.NaN)",
+      "foo(Number.NaN / 2)",
+      "foo(2 / Number.NaN)",
+      "var x; if (x = Number.NaN) { }",
+      "x === Number[NaN];",
+    };
+  }
+
   #[test]
   fn use_isnan_invalid() {
     assert_lint_err! {
