@@ -9,6 +9,7 @@ use deno_ast::swc::ast::Lit::Str;
 use deno_ast::swc::ast::UnaryOp::TypeOf;
 use deno_ast::swc::common::Spanned;
 use deno_ast::swc::visit::{noop_visit_type, Node, Visit};
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct ValidTypeof;
@@ -17,8 +18,8 @@ const CODE: &str = "valid-typeof";
 const MESSAGE: &str = "Invalid typeof comparison value";
 
 impl LintRule for ValidTypeof {
-  fn new() -> Box<Self> {
-    Box::new(ValidTypeof)
+  fn new() -> Arc<Self> {
+    Arc::new(ValidTypeof)
   }
 
   fn tags(&self) -> &'static [&'static str] {
